@@ -27,14 +27,14 @@
 #define __cpuopsys_h_
 
 /*****************************************************************************/
-// Define all OS/CPU-Chip related symbols
+/* Define all OS/CPU-Chip related symbols */
 
-// ***** DOS variations
+/* ***** DOS variations */
 #if defined(__DJGPP__)
 #   define NV_DOS
 #endif
 
-// ***** WINDOWS variations
+/* ***** WINDOWS variations */
 #if defined(_WIN32) || defined(_WIN16)
 #   define NV_WINDOWS
 
@@ -45,38 +45,38 @@
 #   elif !defined(NV_MODS)
 #      define NV_WINDOWS_9X
 #   endif
-#endif  // _WIN32 || defined(_WIN16)
+#endif  /* _WIN32 || defined(_WIN16) */
 
-// ***** Unix variations
+/* ***** Unix variations */
 #if defined(__linux__) && !defined(NV_LINUX) && !defined(NV_VMWARE)
 #   define NV_LINUX
-#endif  // defined(__linux__)
+#endif  /* defined(__linux__) */
 
-// SunOS + gcc
+/* SunOS + gcc */
 #if defined(__sun__) && defined(__svr4__) && !defined(NV_SUNOS)
 #   define NV_SUNOS
-#endif // defined(__sun__) && defined(__svr4__)
+#endif /* defined(__sun__) && defined(__svr4__) */
 
-// SunOS + Sun Compiler (named SunPro, Studio or Forte)
+/* SunOS + Sun Compiler (named SunPro, Studio or Forte) */
 #if defined(__SUNPRO_C) || defined(__SUNPRO_CC)
 #   define NV_SUNPRO_C
 #   define NV_SUNOS
-#endif // defined(_SUNPRO_C) || defined(__SUNPRO_CC)
+#endif /* defined(_SUNPRO_C) || defined(__SUNPRO_CC) */
 
 #if defined(__FreeBSD__) && !defined(NV_BSD)
 #   define NV_BSD
-#endif // defined(__FreeBSD__)
+#endif /* defined(__FreeBSD__) */
 
-// XXXar don't define NV_UNIX on MacOSX or vxworks or dos or QNX
-#if (defined(__unix__) || defined(__unix) ) && !defined(macosx) && !defined(vxworks) && !defined(__DJGPP__) && !defined(NV_UNIX) && !defined(__QNX__) && !defined(__QNXNTO__)// XXX until removed from Makefiles
+/* XXXar don't define NV_UNIX on MacOSX or vxworks or dos or QNX */
+#if (defined(__unix__) || defined(__unix) ) && !defined(macosx) && !defined(vxworks) && !defined(__DJGPP__) && !defined(NV_UNIX) && !defined(__QNX__) && !defined(__QNXNTO__)/* XXX until removed from Makefiles */
 #   define NV_UNIX
-#endif // defined(__unix__)
+#endif /* defined(__unix__) */
 
 #if (defined(__QNX__) || defined(__QNXNTO__)) && !defined(NV_QNX)
 #   define NV_QNX
 #endif
 
-// ***** Apple variations
+/* ***** Apple variations */
 #if defined(macintosh) || defined(__APPLE__)
 #   define NV_MACINTOSH
 #   if defined(__MACH__)
@@ -87,46 +87,46 @@
 #   if defined(__LP64__)
 #      define NV_MACINTOSH_64
 #   endif
-#endif  // defined(macintosh)
+#endif  /* defined(macintosh) */
 
-// ***** VxWorks
-// Tornado 2.21 is gcc 2.96 and #defines __vxworks.
-// Tornado 2.02 is gcc 2.7.2 and doesn't define any OS symbol, so we rely on
-// the build system #defining vxworks.
+/* ***** VxWorks */
+/* Tornado 2.21 is gcc 2.96 and #defines __vxworks. */
+/* Tornado 2.02 is gcc 2.7.2 and doesn't define any OS symbol, so we rely on */
+/* the build system #defining vxworks. */
 #if defined(__vxworks) || defined(vxworks)
 #   define NV_VXWORKS
 #endif
 
-// ***** Integrity OS
+/* ***** Integrity OS */
 #if defined(__INTEGRITY)
 #  if !defined(NV_INTEGRITY)
 #    define NV_INTEGRITY
 #  endif
 #endif
 
-// ***** Processor type variations
-// Note: The prefix NV_CPU_* is taken by \\sw\main\sdk\nvidia\inc\Nvcm.h
+/* ***** Processor type variations */
+/* Note: The prefix NV_CPU_* is taken by \\sw\main\sdk\nvidia\inc\Nvcm.h */
 
-#if ((defined(_M_IX86) || defined(__i386__) || defined(__i386)) && !defined(NVCPU_X86)) // XXX until removed from Makefiles
-    // _M_IX86 for windows, __i386__ for Linux (or any x86 using gcc)
-    // __i386 for Studio compiler on Solaris x86
-#   define NVCPU_X86               // any IA32 machine (not x86-64)
+#if ((defined(_M_IX86) || defined(__i386__) || defined(__i386)) && !defined(NVCPU_X86)) /* XXX until removed from Makefiles */
+/* _M_IX86 for windows, __i386__ for Linux (or any x86 using gcc) */
+/* __i386 for Studio compiler on Solaris x86 */
+#   define NVCPU_X86               /* any IA32 machine (not x86-64) */
 #   define NVCPU_MIN_PAGE_SHIFT 12
 #endif
 
 #if defined(_WIN32) && defined(_M_IA64)
-#   define NVCPU_IA64_WINDOWS      // any IA64 for Windows opsys
+#   define NVCPU_IA64_WINDOWS      /* any IA64 for Windows opsys */
 #endif
 #if defined(NV_LINUX) && defined(__ia64__)
-#   define NVCPU_IA64_LINUX        // any IA64 for Linux opsys
+#   define NVCPU_IA64_LINUX        /* any IA64 for Linux opsys */
 #endif
 #if defined(NVCPU_IA64_WINDOWS) || defined(NVCPU_IA64_LINUX) || defined(IA64)
-#   define NVCPU_IA64              // any IA64 for any opsys
+#   define NVCPU_IA64              /* any IA64 for any opsys */
 #endif
 
 #if (defined(NV_MACINTOSH) && !(defined(__i386__) || defined(__x86_64__)))  || defined(__PPC__) || defined(__ppc)
 #   ifndef NVCPU_PPC
-#   define NVCPU_PPC               // any PowerPC architecture
+#   define NVCPU_PPC               /* any PowerPC architecture */
 #   endif
 #   ifndef NV_BIG_ENDIAN
 #   define NV_BIG_ENDIAN
@@ -134,7 +134,7 @@
 #endif
 
 #if defined(__x86_64) || defined(AMD64) || defined(_M_AMD64)
-#    define NVCPU_X86_64           // any x86-64 for any opsys
+#    define NVCPU_X86_64           /* any x86-64 for any opsys */
 #endif
 
 #if defined(__arm__) || defined(_M_ARM)
@@ -144,14 +144,14 @@
 
 #if defined(__SH4__)
 #   ifndef NVCPU_SH4
-#   define NVCPU_SH4               // Renesas (formerly Hitachi) SH4
+#   define NVCPU_SH4               /* Renesas (formerly Hitachi) SH4 */
 #   endif
 #   if   defined NV_WINDOWS_CE
 #       define NVCPU_MIN_PAGE_SHIFT 12
 #   endif
 #endif
 
-// For Xtensa processors
+/* For Xtensa processors */
 #if defined(__XTENSA__)
 # define NVCPU_XTENSA
 # if defined(__XTENSA_EB__)
@@ -160,37 +160,47 @@
 #endif
 
 
-// Other flavors of CPU type should be determined at run-time.
-// For example, an x86 architecture with/without SSE.
-// If it can compile, then there's no need for a compile time option.
-// For some current GCC limitations, these may be fixed by using the Intel
-// compiler for certain files in a Linux build.
+/*
+ * Other flavors of CPU type should be determined at run-time.
+ * For example, an x86 architecture with/without SSE.
+ * If it can compile, then there's no need for a compile time option.
+ * For some current GCC limitations, these may be fixed by using the Intel
+ * compiler for certain files in a Linux build.
+ */
 
-
-// The minimum page size can be determined from the minimum page shift
+/* The minimum page size can be determined from the minimum page shift */
 #if defined(NVCPU_MIN_PAGE_SHIFT)
 #define NVCPU_MIN_PAGE_SIZE (1 << NVCPU_MIN_PAGE_SHIFT)
 #endif
 
 #if defined(NVCPU_IA64) || defined(NVCPU_X86_64) || defined(NV_MACINTOSH_64)
-#   define NV_64_BITS          // all architectures where pointers are 64 bits
+#   define NV_64_BITS          /* all architectures where pointers are 64 bits */
 #else
-    // we assume 32 bits. I don't see a need for NV_16_BITS.
+/* we assume 32 bits. I don't see a need for NV_16_BITS. */
 #endif
 
-// NOTE: NV_INT64_OK is not needed in the OpenGL driver for any platform
-// we care about these days. The only consideration is that Linux does not
-// have a 64-bit divide on the server. To get around this, we convert the
-// expression to (double) for the division.
+/*
+ * NOTE: NV_INT64_OK is not needed in the OpenGL driver for any platform
+ * we care about these days. The only consideration is that Linux does not
+ * have a 64-bit divide on the server. To get around this, we convert the
+ * expression to (double) for the division.
+ */
 #if (!(defined(macintosh) || defined(vxworks) || defined(__INTEL_COMPILER)) || defined(NV_LINUX)) && !defined(NV_INT64_OK)
 #define NV_INT64_OK
 #endif
 
-// For verification-only features not intended to be included in normal drivers
-#if defined(NV_MODS) && defined(DEBUG) && !defined(NV_DOS) && !defined(VISTA_MFG_MODS) && !defined(LINUX_MFG)
+/* For verification-only features not intended to be included in normal drivers */
+#if defined(NV_MODS) && defined(DEBUG) && !defined(DISABLE_VERIF_FEATURES)
 #define NV_VERIF_FEATURES
 #endif
 
+// Until we make SIM_BUILD vs. NV_VERIF_FEATURES orthogonal in the RM
+// codepaths, a simulation build (previously only arch NV_MODS) also
+// requires NV_VERIF_FEATURES for sims to work properly.
+
+#if defined(SIM_BUILD)
+#define NV_VERIF_FEATURES
+#endif
 
 /*
  * New, safer family of #define's -- these ones use 0 vs. 1 rather than
