@@ -636,8 +636,6 @@ NV_DEFINE_REG_ENTRY(__NV_AGP, NV_DEFAULT_NV_AGP_VALUE);
  * changes to take effect, you need to recompile and reload the NVIDIA
  * kernel module.
  */
-
-
 nv_parm_t nv_parms[] = {
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_ENABLE_VIA_4X),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_ENABLE_ALI_AGP),
@@ -664,8 +662,10 @@ nv_parm_t nv_parms[] = {
     {NULL, NULL, NULL}
 };
 
+#elif defined(NVRM)
+
+extern nv_parm_t nv_parms[];
 
 #endif /* NV_DEFINE_REGISTRY_KEY_TABLE */
 
-
 #endif /* _RM_REG_H_ */
