@@ -404,7 +404,10 @@ void NV_API_CALL os_log_error(
     int l;
     sprintf(nv_error_string, "NVRM: ");
     l = strlen(nv_error_string);
-    vsnprintf(nv_error_string + l, MAX_ERROR_STRING - l, fmt, ap);
+    if (ap != NULL)
+        vsnprintf(nv_error_string + l, MAX_ERROR_STRING - l, fmt, ap);
+    else
+        snprintf(nv_error_string + l, MAX_ERROR_STRING - l, fmt);
     printf("%s", nv_error_string);
 }
 
